pub struct RelativeLayout {
pub placement: RelativePlacement,
pub auto_hide: RelativeAutoHide,
pub auto_hide_request: Callback<()>,
pub uncovered_controls: Vec<Weak<RefCell<dyn ControlObject>>>,
}Expand description
Warning!
RelativeLayout is designed to work with Popup control and it’s dangerous (danger of panic) to use outside of it.
It works correctly only when:
- Covers whole window.
- References only controls on lower layouts.
The lower layout control is a control that:
- is not lying on the path from RelativeLayout to root (that would cause borrow panic during layout phase)
- it’s layout phase is calculated before the layout phase of RelativeLayout (RelativeLayout refers to calculated size of that control)
Fields
placement: RelativePlacementauto_hide: RelativeAutoHideAuto hide method.
Defines rules when to call auto_hide_request callback.
auto_hide_request: Callback<()>Called when auto hide is requested.
uncovered_controls: Vec<Weak<RefCell<dyn ControlObject>>>RelativeLayout does not pass through events to controls below except the area covered by this list of controls
Implementations
Sourceimpl RelativeLayout
impl RelativeLayout
Sourcepub fn builder() -> RelativeLayoutBuilder<((), (), (), ())>
pub fn builder() -> RelativeLayoutBuilder<((), (), (), ())>
Create a builder for building RelativeLayout.
On the builder, call .placement(...)(optional), .auto_hide(...)(optional), .auto_hide_request(...)(optional), .uncovered_controls(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of RelativeLayout.
Sourceimpl RelativeLayout
impl RelativeLayout
pub fn to_view( self, style: Option<Box<dyn Style<Self>>>, context: ViewContext, ) -> Rc<RefCell<dyn ControlObject>>